index_source_id

Function index_source_id 

pub fn index_source_id(
    bundle_root: &Path,
    index_path: &Path,
) -> Option<ConceptId>
Synthesizes the concept id an index.md would have if it were itself a concept, so okf_core::links::Link::resolve_all can resolve its relative links against the index’s own directory.