Module syntax

Module syntax 

Multi-language syntax validation for Attested Computations and embedded scripts.

Provides fast syntax checking for Python, JavaScript, TypeScript, Rust, SQL, JSON, YAML, and Bash using pure Rust AST parsers.

Structs

FencedCodeBlock
A parsed fenced code block from markdown.
SyntaxError
A syntax diagnostic produced by static AST parsing.

Enums

Language
Supported languages for static syntax checking.

Functions

check_syntax
Checks the syntax of source for the given language tag or name.
extract_fenced_code_blocks
Extracts all fenced code blocks (delimited by 3+ backticks or 3+ tildes) from markdown text.